@@ -6,20 +6,28 @@ console = Console(theme=Theme({"repr.str":"#54A24B", "repr.number": "#FF7F0E", "
 
 class DevtoProfile:
     def __init__(self, username):
+        """Dev.to profile inference class
+
+        Args:
+            username (str): Dev.to username
+        """
         self.username = username
-        self.api_url = "https://dev.to/api"
+        self.inference = None
+        self._api_url = "https://dev.to/api"
 
     def perform_inference(self):
-        url = f"{self.api_url}/users/by_username?url={self.username}"
+        """Performs inference on the Dev.to profile
+        
+        Returns:
+            dict: Dev.to profile data
+        """
+        url = f"{self._api_url}/users/by_username?url={self.username}"
         response = requests.get(url)
         if response.status_code == 200:
-            data = response.json()
-            return data
+            self.inference = response.json()
+            console.print(self.inference)
         elif response.status_code == 404:
             raise Exception("Invalid Dev.to username inputted.")
         else:
             raise Exception(f"Error with status code of: {response.status_code}")
-    
-    def pprint_inference(self):
-        data = self.perform_inference()
-        console.print(data)
\ No newline at end of file
+    
\ No newline at end of file
