@@ -2,14 +2,34 @@ import requests
 import re
 from datetime import datetime
 from base64 import b64decode
+from rich.console import Console
+from rich.theme import Theme
+
+console = Console(theme=Theme({"repr.str":"#54A24B", "repr.number": "#FF7F0E", "repr.none":"#808080"}))
 
 class GithubProfile:
     def __init__(self, username, access_token=None):
+        """Github profile inference class
+
+        Args:
+            username (str): Github username
+            access_token (str, optional): Github access token to increase API rate limit and access private repositories. Defaults to None.
+        """
         self.username = username
         self.access_token = access_token
+        self.inference = None
         self._api_url = "https://api.github.com"
 
     def _request(self, url, error_handling=True):
+        """Makes a request to the Github API
+
+        Args:
+            url (str): URL to be requested
+            error_handling (bool, optional): Whether to handle errors or not before returning the response. Defaults to True.
+
+        Returns:
+            str: Response from the API
+        """
         if self.access_token:
             headers = {"Authorization": "token {}".format(self.access_token)}
             response = requests.get(url, headers=headers)
@@ -37,6 +57,14 @@ class GithubProfile:
             return response
     
     def _parse_next_link(self, headers):
+        """Parses the next link from the Github API response headers
+
+        Args:
+            headers (dict): Response headers from the Github API
+
+        Returns:
+            str: Next link
+        """
         if "Link" in headers:
             links = headers["Link"]
             if 'rel="next"' in links:
@@ -47,7 +75,17 @@ class GithubProfile:
         else:
             return None
     
-    def _process_api_response(self, url, item_name="items", json_key=None):
+    def _multipage_request(self, url, item_name="items", json_key=None):
+        """Makes a request to the Github API and handles pagination
+
+        Args:
+            url (str): URL to be requested
+            item_name (str, optional): Name of the items requested, will be used in the message. Defaults to "items".
+            json_key (str, optional): Key of the items in the JSON response. Defaults to None.
+
+        Returns:
+            list: List of items
+        """
         item_list = []
         message = None
         while url:
@@ -64,6 +102,7 @@ class GithubProfile:
         return item_list, message
     
     def _username_token_check(self):
+        """Checks if the Github username is associated with the provided access token, which is called when the user wants to include private repositories"""
         test_url = f"{self._api_url}/user"
         response = self._request(test_url)
         associated_username = response.json()['login']
@@ -71,6 +110,11 @@ class GithubProfile:
             raise Exception("If you want to include private repositories, please ensure that the Github username is associated with the provided access token.")
         
     def _profile_inference(self):
+        """Infer data regarding the user's Github profile
+
+        Returns:
+            dict: Github profile data
+        """
         profile_url = f"{self._api_url}/users/{self.username}"
         response = self._request(profile_url)
         profile_data = response.json()
@@ -91,13 +135,22 @@ class GithubProfile:
     
 
     def _repository_inference(self, top_repo_n=3, include_private=False):
+        """Infer data regarding the user's Github repositories
+
+        Args:
+            top_repo_n (int, optional): Number of top repositories to be included in the inference. Defaults to 3.
+            include_private (bool, optional): Whether to include private repositories in the inference. Defaults to False.
+
+        Returns:
+            dict: Github repository data and statistics
+        """
         if include_private:
             self._username_token_check()
             repo_url = f"{self._api_url}/user/repos?per_page=100"
         else:
             repo_url = f"{self._api_url}/users/{self.username}/repos?per_page=100"
             
-        repos, repo_message = self._process_api_response(repo_url, "repos")
+        repos, repo_message = self._multipage_request(repo_url, "repos")
 
         repos.sort(
             key=lambda r: r["stargazers_count"] + r["forks_count"],
@@ -139,6 +192,14 @@ class GithubProfile:
         return {"stats": stats, "original_repos": original_repos, "repos": repos, "repo_api_message": repo_message}
     
     def _contribution_inference(self, include_private=False):
+        """Infer data regarding the user's Github contributions (issues and pull requests)
+
+        Args:
+            include_private (bool, optional): Whether to include private repositories in the inference. Defaults to False.
+
+        Returns:
+            dict: Github contribution data and statistics
+        """
         if include_private:
             self._username_token_check()
             issue_url = f"{self._api_url}/search/issues?q=type:issue author:{self.username}&sort=author-date&order=desc&per_page=100"
@@ -147,8 +208,8 @@ class GithubProfile:
             issue_url = f"{self._api_url}/search/issues?q=type:issue author:{self.username} is:public&sort=author-date&order=desc&per_page=100"
             pr_url = f"{self._api_url}/search/issues?q=type:pr author:{self.username} is:public&sort=author-date&order=desc&per_page=100"
             
-        issue_data, issue_message = self._process_api_response(issue_url, "issues", "items")
-        pr_data, pr_message = self._process_api_response(pr_url, "PRs", "items")
+        issue_data, issue_message = self._multipage_request(issue_url, "issues", "items")
+        pr_data, pr_message = self._multipage_request(pr_url, "PRs", "items")
         issues, prs = [], []
 
         for i in issue_data:
@@ -200,13 +261,23 @@ class GithubProfile:
 
         return {'contribution': contribution, 'issue_api_message': issue_message, 'pr_api_message': pr_message}
     
-    def _activity_inference(self, repos, top_repo_n=3, include_private=False):
+    def _activity_inference(self, original_repos, top_repo_n=3, include_private=False):
+        """Infer data regarding the user's Github activity (commits)
+
+        Args:
+            original_repos (dict): Original repository data (from _repo_inference)
+            top_repo_n (int, optional): Number of top repositories to be included in the inference. Defaults to 3.
+            include_private (bool, optional): Whether to include private repositories in the inference. Defaults to False.
+
+        Returns:
+            dict: Github activity data and statistics
+        """
         if include_private:
             self._username_token_check()
             commit_url = self._api_url + f"/search/commits?q=committer:{self.username}&sort=committer-date&order=desc&per_page=100"
         else:
             commit_url = self._api_url + f"/search/commits?q=committer:{self.username} is:public&sort=committer-date&order=desc&per_page=100"
-        commit_data, commit_message = self._process_api_response(commit_url, "commits", "items")
+        commit_data, commit_message = self._multipage_request(commit_url, "commits", "items")
 
         commits = []
         for c in commit_data:
@@ -251,7 +322,7 @@ class GithubProfile:
                 
         most_active_repo_name = list(sorted_counts['owned_repo'].keys())[:top_repo_n]
         most_active_repo = []
-        for r in repos:
+        for r in original_repos:
             if r['name'] in most_active_repo_name:
                 most_active_repo.append({
                     'name': r['name'],
@@ -286,6 +357,17 @@ class GithubProfile:
         return {'activity': activity, 'most_active_repo': most_active_repo, 'commit_api_message': commit_message}
     
     def _skill_inference(self, bio, original_repos, repo_message, top_language_n=3):
+        """Infer data regarding the user's skills from their Github bio and repositories.
+
+        Args:
+            bio (str): The user's Github bio
+            original_repos (dict): Original repository data (from _repo_inference)
+            repo_message (str): Message from _repo_inference
+            top_language_n (int): Number of top languages to be included in the inference. Defaults to 3.
+
+        Returns:
+            dict: Inferred data regarding the user's skills
+        """
         response = requests.get("https://raw.githubusercontent.com/supertypeai/collective/main/src/data/profileTagsChoices.json")
         keywords = response.json()
         
@@ -340,16 +422,25 @@ class GithubProfile:
             }
     
     def perform_inference(self, top_repo_n=3, top_language_n=3, include_private=False):
+        """Perform inference on the user's Github profile. This will print out a dictionary that includes data and statistics regarding their profile, repository, skill, activity, and contribution. The dictionary will also be stored in the inference attribute.
+
+        Args:
+            top_repo_n (int, optional): Number of top repositories to be included in the inference. Defaults to 3.
+            top_language_n (int, optional): Number of top languages to be included in the inference. Defaults to 3.
+            include_private (bool, optional): Whether to include private repositories in the inference. Defaults to False.
+        """
         profile = self._profile_inference()
         repository = self._repository_inference(top_repo_n=top_repo_n, include_private=include_private)
-        skill = self._skill_inference(profile['bio'], repository['original_repos'], repository['repo_api_message'], top_language_n=top_language_n)
-        activity = self._activity_inference(repos= repository['original_repos'], top_repo_n=top_repo_n, include_private=include_private)
+        skill = self._skill_inference(bio=profile['bio'], original_repos=repository['original_repos'], repo_message=repository['repo_api_message'], top_language_n=top_language_n)
+        activity = self._activity_inference(original_repos=repository['original_repos'], top_repo_n=top_repo_n, include_private=include_private)
         contribution = self._contribution_inference(include_private=include_private)
         
-        return {
+        self.inference = {
             "profile": profile,
             "skill": skill,
             "stats": repository["stats"],
             "activity": activity,
             "contribution": contribution
-        }
\ No newline at end of file
+        }
+        
+        console.print(self.inference)
\ No newline at end of file
